Python Client for Analytics Admin API
=================================================

|alpha| |pypi| |versions|

`Analytics Admin API`_

- `Client Library Documentation`_
- `Product Documentation`_

.. |alpha| image:: https://img.shields.io/badge/support-beta-orange.svg
   :target: https://github.com/googleapis/google-cloud-python/blob/master/README.rst#beta-support
.. |pypi| image:: https://img.shields.io/pypi/v/google-analytics-admin.svg
   :target: https://pypi.org/project/google-analytics-admin/
.. |versions| image:: https://img.shields.io/pypi/pyversions/google-analytics-admin.svg
   :target: https://pypi.org/project/google-analytics-admin/
.. _Analytics Admin API: https://developers.google.com/analytics/
.. _Client Library Documentation: https://googleapis.dev/python/analyticsadmin/latest
.. _Product Documentation:  https://developers.google.com/analytics/

Installation
~~~~~~~~~~~~

Install this library in a `virtualenv`_ using pip. `virtualenv`_ is a tool to
create isolated Python environments. The basic problem it addresses is one of
dependencies and versions, and indirectly permissions.

With `virtualenv`_, it's possible to install this library without needing system
install permissions, and without clashing with the installed system
dependencies.

.. _`virtualenv`: https://virtualenv.pypa.io/en/latest/


Mac/Linux
^^^^^^^^^

.. code-block:: console

    pip install virtualenv
    virtualenv <your-env>
    source <your-env>/bin/activate
    <your-env>/bin/pip install google-analytics-admin


Windows
^^^^^^^

.. code-block:: console

    pip install virtualenv
    virtualenv <your-env>
    <your-env>\Scripts\activate
    <your-env>\Scripts\pip.exe install google-analytics-admin

Next Steps
~~~~~~~~~~

-  Read the `Client Library Documentation`_ for Analytics Admin API
   to see other available methods on the client.
-  Read the `Analytics Admin API Product documentation`_ to learn
   more about the product and see How-to Guides.

.. _Analytics Admin API Product documentation:  https://developers.google.com/analytics/